unit ModuleBase;

interface

uses
  Classes, SysUtils, ModularSystem, UGenerics, UWebPage, UWebApp,
  WebSession, UHTTPServer;

type
  TGeneratePageEvent = procedure (Session: TWebSession; Page: TWebPage) of object;

  { TModuleBase }

  TModuleBase = class(TModule)
  private
    PageAdmin: TWebPage;
    FOnGeneratePage: TGeneratePageEvent;
  public
    Session: TWebSession;
    Pages: TPageList;
    HandlerData: THTTPHandlerData;
    constructor Create(Owner: TComponent); override;
    procedure Start; override;
    procedure Stop; override;
    property OnGeneratePage: TGeneratePageEvent read FOnGeneratePage write FOnGeneratePage;
  end;


implementation

uses
  PageAdmin;

{ TModuleBase }

constructor TModuleBase.Create(Owner: TComponent);
begin
  inherited Create(Owner);
  Identification := 'Base';
  Title := 'Base application module';
  Version := '1.0';
  License := 'GNU/LGPL v3';
  Author := 'Chronosoft';
  Dependencies.Add('System');
end;

procedure TModuleBase.Start;
begin
  BeforeStart;
  Pages := TPageList.Create;
  with Pages do begin
    PageAdmin := TPageAdmin.Create(nil);
    RegisterPage(PageAdmin, 'administration');
  end;
  AfterStart;
end;

procedure TModuleBase.Stop;
begin
  BeforeStop;
  with Pages do begin
    UnregisterPage(PageAdmin);
    FreeAndNil(PageAdmin);
  end;
  FreeAndNil(Pages);
  AfterStop;
end;

end.

