unit ModuleFinance;

interface

uses
  Classes, SysUtils, ModularSystem, ModuleBase, UWebPage;

type

  { TModuleUser }

  TModuleFinance = class(TModule)
  private
    WebPageFinance: TWebPage;
  public
    ModuleBase: TModuleBase;
    constructor Create(Owner: TComponent); override;
    procedure Start; override;
    procedure Stop; override;
    procedure Install; override;
    procedure Uninstall; override;
  end;


implementation

uses
  Core, PageFinance, USqlDatabase;

{ TModuleFinance }

constructor TModuleFinance.Create(Owner: TComponent);
begin
  inherited;
  Identification := 'Finance';
  Title := 'Accounting management';
  Version := '1.0';
  License := 'GNU/LGPL v3';
  Author := 'Chronosoft';
  Dependencies.Add('Base');
end;

procedure TModuleFinance.Start;
begin
  BeforeStart;
  ModuleBase := TModuleBase(Manager.FindModuleByName('Base'));
  WebPageFinance := TWebPageFinance.Create(nil);
  ModuleBase.Pages.RegisterPage(WebPageFinance, 'finance');
  //RegisterPage(TUserControlPage, UserControlPage, '');
  AfterStart;
end;

procedure TModuleFinance.Stop;
begin
  BeforeStop;
  ModuleBase.Pages.UnregisterPage(WebPageFinance);
  FreeAndNil(WebPageFinance);
  ModuleBase := nil;
  AfterStop;
end;

procedure TModuleFinance.Install;
var
  DbRows: TDbRows;
begin
  try
    DbRows := TDbRows.Create;

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `FinanceTariff` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Name` varchar(32) COLLATE utf8_czech_ci NOT NULL,' +
    '  `Group` int(11) NOT NULL DEFAULT "0",' +
    '  `SpeedMin` int(11) NOT NULL DEFAULT "0",' +
    '  `SpeedMax` int(11) NOT NULL DEFAULT "0",' +
    '  `UploadAsymmetry` int(11) NOT NULL DEFAULT "1",' +
    '  `Price` int(11) NOT NULL DEFAULT "0",' +
    '  `MemberCount` int(11) NOT NULL DEFAULT "0",' +
    '  `ReplaceId` int(11) DEFAULT NULL,' +
    '  `Public` int(11) NOT NULL DEFAULT "1",' +
    '  PRIMARY KEY (`Id`),' +
    '  KEY `ReplaceId` (`ReplaceId`),' +
    '  KEY `Public` (`Public`)' +
    ') ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1 ;');

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `FinanceYear` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Year` int(11) NOT NULL,' +
    '  `DateStart` date NOT NULL,' +
    '  `DateEnd` date NOT NULL,' +
    '  PRIMARY KEY (`Id`)' +
    ') ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1 ;');

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `DocumentLine` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Name` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  `Shortcut` varchar(16) COLLATE utf8_czech_ci NOT NULL,' +
    '  PRIMARY KEY (`Id`),' +
    '  UNIQUE KEY `Shortcut` (`Shortcut`)' +
    ') ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1; ');

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `DocumentLineSequence` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `DocumentLine` int(11) NOT NULL,' +
    '  `FinanceYear` int(11) NOT NULL,' +
    '  `NextNumber` int(11) NOT NULL,' +
    '  `YearPrefix` int(11) NOT NULL,' +
    '  PRIMARY KEY (`Id`),' +
    '  KEY `DocumentLine` (`DocumentLine`),' +
    '  KEY `FinanceYear` (`FinanceYear`)' +
    ') ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1 ;');

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `FinanceBankAccount` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `TimeCreate` date NOT NULL,' +
    '  `Number` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  `Comment` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  PRIMARY KEY (`Id`)' +
    ') ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1; ');

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `FinanceBillingPeriod` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Name` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  `MonthCount` int(11) NOT NULL,' +
    '  PRIMARY KEY (`Id`)' +
    ') ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1 ;');

  finally
    DbRows.Free;
  end;
  inherited;
end;

procedure TModuleFinance.Uninstall;
var
  DbRows: TDbRows;
begin
  inherited;
  try
    DbRows := TDbRows.Create;
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `FinanceBillingPeriod`');
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `FinanceBankAccount`');
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `DocumentLine`');
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `DocumentLineSequence`');
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `FinanceTariff`');
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `FinanceYear`');
  finally
    DbRows.Free;
  end;
end;

end.

