unit ModuleIS;

interface

uses
  Classes, SysUtils, ModularSystem, USqlDatabase, ModuleBase, Generics;

type

  { TModuleIS }

  TModuleIS = class(TModule)
  private
  public
    ModuleBase: TModuleBase;
    constructor Create(Owner: TComponent); override;
    destructor Destroy; override;
    procedure Start; override;
    procedure Stop; override;
    procedure Install; override;
    procedure Uninstall; override;
    procedure Upgrade; override;
  end;


implementation

uses
  Core, PagePortal;

{ TModuleIS }

constructor TModuleIS.Create(Owner: TComponent);
begin
  inherited;
  Identification := 'IS';
  Title := 'Data management';
  Version := '1.0';
  License := 'GNU/LGPL v3';
  Author := 'Chronosoft';
  Dependencies.Add('Base');
end;

destructor TModuleIS.Destroy;
begin
  inherited;
end;

procedure TModuleIS.Start;
begin
  BeforeStart;
  ModuleBase := TModuleBase(Manager.FindModuleByName('Base'));
  //ModuleBase.Pages.RegisterPage(TWebPagePortal, WebPagePortal, 'portal');
  AfterStart;
end;

procedure TModuleIS.Stop;
begin
  BeforeStop;
  //ModuleBase.Pages.UnregisterPage('portal');
  ModuleBase := nil;
  AfterStop;
end;

procedure TModuleIS.Install;
var
  DbRows: TDbRows;
  Data: TDictionaryStringString;
begin
  try
    DbRows := TDbRows.Create;
    Data := TDictionaryStringString.Create;

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `User` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Name` varchar(255) NOT NULL,' +
    '  `FullName` varchar(255) NOT NULL,' +
    '  `Password` varchar(255) NOT NULL,' +
    '  `Salt` varchar(255) NOT NULL,' +
    '  `Email` varchar(255) NOT NULL,' +
    '  `RegistrationTime` datetime NOT NULL,' +
    '  PRIMARY KEY (`Id`)' +
    ') ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;');

    Data.Add('Id', '1');
    Data.Add('Name', 'anonymous');
    Data.Add('FullName', 'Anonymous');
    Data.Add('RegistrationTime', 'NOW()');
    Data.Add('Password', '');
    Data.Add('Salt', '');
    Data.Add('Email', '');
    Core.Core.CommonDatabase.Insert('User', Data);

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `UserOnline` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `User` int(11) NOT NULL DEFAULT ''0'',' +
    '  `ActivityTime` datetime NOT NULL DEFAULT ''0000-00-00 00:00:00'',' +
    '  `LoginTime` datetime NOT NULL DEFAULT ''0000-00-00 00:00:00'',' +
    '  `SessionId` varchar(255) COLLATE utf8_czech_ci NOT NULL DEFAULT '''',' +
    '  `IpAddress` varchar(16) COLLATE utf8_czech_ci NOT NULL DEFAULT '''',' +
    '  `HostName` varchar(255) COLLATE utf8_czech_ci NOT NULL DEFAULT '''',' +
    '  `ScriptName` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  PRIMARY KEY (`Id`),' +
    '  KEY `User` (`User`)' +
    ') ENGINE=MEMORY  DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1 ;');
  finally
    Data.Free;
    DbRows.Free;
  end;
  inherited Install;
end;

procedure TModuleIS.Uninstall;
var
  DbRows: TDbRows;
begin
  inherited Uninstall;
  try
    DbRows := TDbRows.Create;
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `User`');
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `UserOnline`');
  finally
    DbRows.Free;
  end;
end;

procedure TModuleIS.Upgrade;
begin
  inherited;
end;

end.

