unit ModuleNetwork;

interface

uses
  Classes, SysUtils, ModularSystem, ModuleBase, UWebPage;

type

  { TModuleNetwork }

  TModuleNetwork = class(TModule)
  private
    WebPageNetwork: TWebPage;
  public
    ModuleBase: TModuleBase;
    constructor Create(Owner: TComponent); override;
    destructor Destroy; override;
    procedure Start; override;
    procedure Stop; override;
    procedure Install; override;
    procedure Uninstall; override;
    procedure Upgrade; override;
  end;


implementation

uses
  Core, PageNetwork, USqlDatabase;

{ TModuleNetwork }

constructor TModuleNetwork.Create(Owner: TComponent);
begin
  inherited;
  Identification := 'Network';
  Title := 'Network management';
  Version := '1.0';
  License := 'GNU/LGPL v3';
  Author := 'Chronosoft';
  Dependencies.Add('Base');
end;

destructor TModuleNetwork.Destroy;
begin
  inherited;
end;

procedure TModuleNetwork.Start;
begin
  BeforeStart;
  ModuleBase := TModuleBase(Manager.FindModuleByName('Base'));
  WebPageNetwork := TWebPageNetwork.Create(nil);
  ModuleBase.Pages.RegisterPage(WebPageNetwork, 'sit');
  //RegisterPage(TUserControlPage, UserControlPage, '');
  AfterStart;
end;

procedure TModuleNetwork.Stop;
begin
  BeforeStop;
  ModuleBase.Pages.UnregisterPage(WebPageNetwork);
  FreeAndNil(WebPageNetwork);
  ModuleBase := nil;
  AfterStop;
end;

procedure TModuleNetwork.Install;
var
  DbRows: TDbRows;
begin
  try
    DbRows := TDbRows.Create;

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `NetworkConfiguration` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Caption` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  `Execute` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  `Changed` int(11) NOT NULL DEFAULT "0",' +
    '  `LastTime` datetime NOT NULL DEFAULT "0000-00-00 00:00:00",' +
    '  `ExecutionTime` int(11) NOT NULL,' +
    '  `Enabled` int(11) NOT NULL DEFAULT "1",' +
    '  `Period` int(11) NOT NULL DEFAULT "60",' +
    '  `Log` mediumtext COLLATE utf8_czech_ci NOT NULL,' +
    '  PRIMARY KEY (`Id`)' +
    ') ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1; ');

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `NetworkDevice` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Name` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  `Member` int(11) NOT NULL COMMENT "Member",' +
    '  `Location` int(11) NOT NULL COMMENT "Member",' +
    '  `Type` int(11) NOT NULL COMMENT "NetworkDeviceType",' +
    '  `PositionLatitude` double NOT NULL DEFAULT "0",' +
    '  `PositionLongitude` double NOT NULL DEFAULT "0",' +
    '  `Used` int(11) NOT NULL DEFAULT "1",' +
    '  `Online` int(11) NOT NULL DEFAULT "0",' +
    '  `LastOnline` datetime NOT NULL,' +
    '  `PermanentOnline` int(11) NOT NULL DEFAULT "0",' +
    '  `InboundNATPriority` int(11) NOT NULL DEFAULT "1",' +
    '  PRIMARY KEY (`Id`),' +
    '  UNIQUE KEY `Name` (`Name`),' +
    '  KEY `Member` (`Member`),' +
    '  KEY `Location` (`Location`),' +
    '  KEY `Type` (`Type`)' +
    ') ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1 ;');

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `NetworkInterface` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Name` varchar(16) COLLATE utf8_czech_ci NOT NULL,' +
    '  `Type` int(11) NOT NULL,' +
    '  `MAC` varchar(17) COLLATE utf8_czech_ci NOT NULL,' +
    '  `LocalIP` varchar(16) COLLATE utf8_czech_ci NOT NULL,' +
    '  `IPv6` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  `ExternalIP` varchar(16) COLLATE utf8_czech_ci NOT NULL,' +
    '  `Device` int(11) NOT NULL,' +
    '  `Online` int(11) NOT NULL DEFAULT "0",' +
    '  `LastOnline` datetime NOT NULL,' +
    '  PRIMARY KEY (`Id`),' +
    '  KEY `Device` (`Device`),' +
    '  KEY `Type` (`Type`)' +
    ') ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1 ;');

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `NetworkInterfaceType` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Name` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  `MaxSpeed` int(11) NOT NULL,' +
    '  `FullDuplex` int(11) NOT NULL DEFAULT "1",' +
    '  `Color` varchar(6) COLLATE utf8_czech_ci NOT NULL DEFAULT "ffffff",' +
    '  PRIMARY KEY (`Id`)' +
    ') ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1 ;');

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `NetworkDeviceType` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Name` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  `ShowOnline` int(11) NOT NULL DEFAULT "0",' +
    '  `IconName` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  PRIMARY KEY (`Id`)' +
    ') ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1 ;');

  finally
    DbRows.Free;
  end;
  inherited;
end;

procedure TModuleNetwork.Uninstall;
var
  DbRows: TDbRows;
begin
  inherited Uninstall;
  try
    DbRows := TDbRows.Create;
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `NetworkInterfaceType`');
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `NetworkInterface`');
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `NetworkDeviceType`');
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `NetworkDevice`');
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `NetworkConfiguration`');
  finally
    DbRows.Free;
  end;
end;

procedure TModuleNetwork.Upgrade;
begin
  inherited;
end;

end.

