unit ModuleNews;

interface

uses
  Classes, SysUtils, ModularSystem, ModuleBase, News, UHTTPServer, ModuleUser;

type
  { TModuleNews }

  TModuleNews = class(TModule)
  public
    ModuleBase: TModuleBase;
    News: TNews;
    function Show(HandlerData: THTTPHandlerData): string;
    constructor Create(Owner: TComponent); override;
    destructor Destroy; override;
    procedure Start; override;
    procedure Stop; override;
    procedure Install; override;
    procedure Uninstall; override;
    procedure Upgrade; override;
  end;


implementation

uses
  Core, UserControlPage, USqlDatabase;

{ TModuleNews }

function TModuleNews.Show(HandlerData: THTTPHandlerData): string;
begin
  Result := News.Show(HandlerData);
end;

constructor TModuleNews.Create(Owner: TComponent);
begin
  inherited;
  Identification := 'News';
  Title := 'News and news groups';
  Version := '1.0';
  License := 'GNU/LGPL v3';
  Author := 'Chronosoft';
  Dependencies.Add('User');
end;

destructor TModuleNews.Destroy;
begin
  inherited;
end;

procedure TModuleNews.Start;
begin
  BeforeStart;
  ModuleBase := TModuleBase(Manager.FindModuleByName('Base'));
  //UserControlPage := TUserControlPage.Create(nil);
  //ModuleBase.Pages.RegisterPage(UserControlPage, 'uzivatel');
  //RegisterPage(TUserControlPage, UserControlPage, '');
  News := TNews.Create;
  News.ModuleUser := TModuleUser(Manager.FindModuleByName('User'));
  News.Database := ModuleBase.Session.Database;
  News.ModuleBase := ModuleBase;
  AfterStart;
end;

procedure TModuleNews.Stop;
begin
  BeforeStop;
  FreeAndNil(News);
  //ModuleBase.Pages.UnregisterPage(UserControlPage);
  //FreeAndNil(UserControlPage);
  ModuleBase := nil;
  AfterStop;
end;

procedure TModuleNews.Install;
var
  DbRows: TDbRows;
begin
  try
    DbRows := TDbRows.Create;

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `News` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Title` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  `Content` text COLLATE utf8_czech_ci NOT NULL,' +
    '  `Date` datetime NOT NULL DEFAULT "0000-00-00 00:00:00",' +
    '  `TargetDate` datetime NOT NULL DEFAULT "0000-00-00 00:00:00",' +
    '  `Author` varchar(32) COLLATE utf8_czech_ci NOT NULL,' +
    '  `IP` varchar(16) COLLATE utf8_czech_ci NOT NULL,' +
    '  `Category` int(11) DEFAULT "0",' +
    '  `Enclosure` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  `User` int(11) NOT NULL DEFAULT "0",' +
    '  `Link` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  PRIMARY KEY (`Id`),' +
    '  KEY `category` (`Category`),' +
    '  KEY `date` (`Date`),' +
    '  KEY `Title` (`Title`),' +
    '  KEY `Link` (`Link`)' +
    ') ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1 ;');

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `NewsCategory` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Caption` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  `Permission` int(11) NOT NULL DEFAULT "0",' +
    '  `Sequence` int(11) NOT NULL,' +
    '  `Group` int(11) NOT NULL DEFAULT "1",' +
    '  `RSS` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  PRIMARY KEY (`Id`),' +
    '  KEY `Sequence` (`Sequence`),' +
    '  KEY `Group` (`Group`)' +
    ') ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1; ');

    Core.Core.CommonDatabase.Query(DbRows,
    'ALTER TABLE `News`' +
    '  ADD CONSTRAINT `News_ibfk_1` FOREIGN KEY (`Category`) REFERENCES `NewsCategory` (`Id`);');
  finally
    DbRows.Free;
  end;
  inherited;
end;

procedure TModuleNews.Uninstall;
var
  DbRows: TDbRows;
begin
  inherited;
  try
    DbRows := TDbRows.Create;

    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `News`');
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `NewsGroup`');
  finally
    DbRows.Free;
  end;
end;

procedure TModuleNews.Upgrade;
begin
  inherited;
end;

end.

