unit ModulePortal;

interface

uses
  Classes, SysUtils, ModularSystem, USqlDatabase, Utils, WebSession, User,
  UWebPage, UHtmlClasses, ModuleBase, ModuleUser, ModuleNews, UGenerics;

type

  { TModulePortal }

  TModulePortal = class(TModule)
  private
    Time: TDateTime;
    WebPagePortal: TWebPage;
    function ShowFooter(Session: TWebSession): string;
    function ShowHeader(Session: TWebSession): string;
    procedure GeneratePage(ASession: TWebSession; Page: TWebPage);
  public
    ModuleBase: TModuleBase;
    ModuleUser: TModuleUser;
    constructor Create(Owner: TComponent); override;
    destructor Destroy; override;
    procedure Start; override;
    procedure Stop; override;
    procedure Install; override;
    procedure Uninstall; override;
    procedure Upgrade; override;
  end;


implementation

uses
  Core, PagePortal;

{ TModulePortal }

constructor TModulePortal.Create(Owner: TComponent);
begin
  inherited;
  Identification := 'Portal';
  Title := 'Intranet user portal';
  Version := '1.0';
  License := 'GNU/LGPL v3';
  Author := 'Chronosoft';
  Dependencies.Add('User');
  Dependencies.Add('Finance');
  Dependencies.Add('News');
end;

destructor TModulePortal.Destroy;
begin
  inherited;
end;

procedure TModulePortal.Start;
begin
  BeforeStart;
  ModuleBase := TModuleBase(Manager.FindModuleByName('Base'));
  ModuleBase.OnGeneratePage := GeneratePage;
  WebPagePortal := TWebPagePortal.Create(nil);
  ModuleBase.Pages.RegisterPage(WebPagePortal, '');
  ModuleUser := TModuleUser(Manager.FindModuleByName('User'));
  TWebPagePortal(WebPagePortal).ModuleUser := ModuleUser;
  TWebPagePortal(WebPagePortal).ModuleNews := TModuleNews(Manager.FindModuleByName('News'));
  AfterStart;
end;

procedure TModulePortal.Stop;
begin
  BeforeStop;
  ModuleBase.Pages.UnregisterPage(WebPagePortal);
  FreeAndNil(WebPagePortal);
  ModuleBase := nil;
  ModuleUser := nil;
  AfterStop;
end;

procedure TModulePortal.Install;
var
  DbRows: TDbRows;
begin
  try
    DbRows := TDbRows.Create;

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `Panel` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Module` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  `Parameters` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  `Order` int(11) NOT NULL,' +
    '  `PanelColumn` int(11) NOT NULL,' +
    '  PRIMARY KEY (`Id`),' +
    '  KEY `PanelColumn` (`PanelColumn`)' +
    ') ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1 ;');

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `PanelColumn` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Width` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  PRIMARY KEY (`Id`)' +
    ') ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1 ;');

    Core.Core.CommonDatabase.Query(DbRows,
    'ALTER TABLE `Panel`' +
    '  ADD CONSTRAINT `Panel_ibfk_1` FOREIGN KEY (`PanelColumn`) REFERENCES `panelcolumn` (`Id`);');

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `HyperlinkGroup` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Name` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  PRIMARY KEY (`Id`)' +
    ') ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1 ;');

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `Hyperlink` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Name` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  `URL` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  `Group` int(11) NOT NULL,' +
    '  `IconFile` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  `PermissionModule` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  `PermissionOperation` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  `Enable` int(11) NOT NULL DEFAULT "1",' +
    '  PRIMARY KEY (`Id`),' +
    '  KEY `Group` (`Group`),' +
    '  KEY `Enable` (`Enable`)' +
    ') ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1 ;');

    Core.Core.CommonDatabase.Query(DbRows,
    'ALTER TABLE `Hyperlink`' +
    '  ADD CONSTRAINT `Hyperlink_ibfk_1` FOREIGN KEY (`Group`) REFERENCES `hyperlinkgroup` (`Id`);');

  finally
    DbRows.Free;
  end;
  inherited;
end;

procedure TModulePortal.Uninstall;
var
  DbRows: TDbRows;
begin
  inherited Uninstall;
  try
    DbRows := TDbRows.Create;
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `Panel`');
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `PanelColumn`');
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `Hyperlink`');
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `HyperlinkGroup`');
  finally
    DbRows.Free;
  end;
end;

procedure TModulePortal.Upgrade;
begin
  inherited;
end;

function TModulePortal.ShowHeader(Session: TWebSession): string;
var
  ScriptName: string;
  PathTreePath: string;
  Navigation: string;
  ScriptNameParts: TListString;
  ScriptNamePart: string;
  I: Integer;
  BodyParam: string;
  Path: string;
  Output: string;
begin
  try
    ScriptNameParts := TListString.Create;
    Navigation := '';
    Path := '';
    ScriptName := '';

    //ScriptName := $_SERVER['SCRIPT_NAME'];
    while Pos('//', ScriptName) > 0 do
      ScriptName := StringReplace('//', '/', ScriptName, [rfReplaceAll]);
    PathTreePath := '/';
    //PathTreeItem := PathTree;
    //Navigation := '<a href="' + NavigationLink(PathTreePath) + '">' + PathTreeItem[0] + '</a> &gt; ';
    ScriptName := Copy(ScriptName, Length(Core.Core.BaseURL), Length(ScriptName));
    ScriptNameParts.Explode('/', ScriptName);
    ScriptNameParts.Delete(0);
    (*
    for I := 0 to ScriptNameParts.Count - 1 do begin
      ScriptNamePart := ScriptNameParts[I];
      //echo($ScriptNamePart.'<br />');
      if array_key_exists($ScriptNamePart, $PathTreeItem) then begin
        if  is_array($PathTreeItem[$ScriptNamePart]) then begin

          PathTreeItem = $PathTreeItem[$ScriptNamePart];
          PathTreePath .= $ScriptNamePart.'/';
          if PathTreeItem[0] != '' then
            Navigation := Navigation + '<a href="' + $this->System->Config['Web']['RootFolder'] + PathTreePath + '">' + PathTreeItem[0] + '</a> &gt; ';
        end else begin
          if(PathTreeItem[ScriptNamePart] != '')
            Navigation := Navigation + '<a href="' + $this->System->Config['Web']['RootFolder'].$PathTreePath.$ScriptNamePart.'">'.$PathTreeItem[$ScriptNamePart].'</a> &gt; ';
        end;
      end;
    end;    *)
    Navigation := Copy(Navigation, 1, Length(Navigation) - 6);

    BodyParam := '';
    //if(isset($this->Load)) BodyParam := BodyParam + ' onload="'.$this->Load.'"';
    //if(isset($this->Unload)) BodyParam := BodyParam + ' onunload="'.$this->Unload.'"';
    Output := '<?xml version="1.0" encoding="' + Core.Core.Charset + '"?>' + LineEnding +
    '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">' +
    '<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="cs" lang="cs">' +
    '<head><link rel="stylesheet" href="' + NavigationLink('/style/' + Core.Core.Style + '/style.css') + '" type="text/css" media="all" />' +
    '<meta http-equiv="content-type" content="application/xhtml+xml; charset=' + Core.Core.Charset + '" />' +
    '<script type="text/javascript" src="' + Core.Core.BaseURL + '/style/' + Core.Core.Style + '/global.js"></script>' +
    '<title>' + Session.GlobalTitle + ' - ' + Path + '</title>' +
    '</head><body' + BodyParam + '>' +
    '<div id="Title">' + Title + '</div>' +
    '<div class="Navigation"><span class="MenuItem"><strong>Navigace :: </strong> ';
    Output := Output + Navigation + '</span><div class="MenuItem2">';
    if Assigned(ModuleUser) then begin
    if ModuleUser.User.Id = UnknownUser then
      Output := Output + '<a href="' + MakeLink('Přihlášení',
        NavigationLink('/?Action=LoginForm')) + ' ' +
        MakeLink('Registrace', NavigationLink('/?Action=UserRegister'))
      else Output := Output + ModuleUser.User.Name + ' ' + MakeLink('Odhlásit',
        NavigationLink('/?Action=Logout'));
    end;
// <a href="'.$this->System->Config['Web']['RootFolder'].'/?Action=UserOptions">Nastavení</a>';
  Output := Output + '</div></div>';
  Result := Output;
  finally
    ScriptNameParts.Free;
  end;
end;

procedure TModulePortal.GeneratePage(ASession: TWebSession; Page: TWebPage);
var
  I: Integer;
  TitleTag: THtmlString;
begin
  with ASession do begin
    HtmlDocument.ContentLanguage := 'cs';
    GlobalTitle := 'Portál';
    HtmlDocument.Styles.Add(NavigationLink('/Style/' + TCore(MainModule).Style + '/Style.css'));
    HtmlDocument.Scripts.Add(NavigationLink('/Style/' + TCore(MainModule).Style + '/Global.js'));
    HtmlDocument.Scripts.Add(NavigationLink('/Style/' + TCore(MainModule).Style + '/jquery.js'));

      TitleTag := THtmlString.Create;
      //TitleTag.Text := ShowHeader(ASession);
      HtmlDocument.Body.SubItems.Insert(0, TitleTag);
      TitleTag := THtmlString.Create;
      TitleTag.Text := ShowFooter(ASession);
      HtmlDocument.Body.SubItems.Insert(0, TitleTag);
      //Page.Page.OnProduce(HandlerData);
      HtmlDocument.Title := Page.Caption;
      TitleTag.Text := '<div class="TitlePanel"><span class="GlobalTitle">' + GlobalTitle +
        '</span> - ' + HtmlDocument.Title + '</div>';
      HtmlDocument.Title := GlobalTitle + ' - ' + HtmlDocument.Title;
      with HtmlDocument.AsXmlDocument do
      try
        Formated := TCore(MainModule).FormatHTML;
        Response.Content.WriteString(AsString);
      finally
        Free;
      end;
    end;
end;

function TModulePortal.ShowFooter(Session: TWebSession): string;
begin
  Result := '';
  //Time := Round(Now - $ScriptTimeStart, 2);
  Result := Result + '<div id="Footer">' +
    '<i>| Správa webu: ' + Core.Core.Admin + ' | e-mail: ' + Core.Core.AdminEmail + ' |';
//    if Core.ShowRuntimeInfo then Output := Output + ' Doba generování: ' +
//     Time + ' s / ' + ini_get('max_execution_time') + ' s | Použitá paměť: ' +
//     HumanSize(memory_get_peak_usage(FALSE)) + ' / ' + ini_get('memory_limit') + 'B |';
  Result := Result + '</i></div></body></html>';
end;

end.

