unit PagePortal;

interface

uses
  Classes, SysUtils, FileUtil, UWebPage, UHTTPServer, USqlDatabase, Utils,
  Generics, WebSession, UHtmlClasses, ModularSystem, ModuleUser,
  ModuleNews;

type

  { TWebPagePortal }

  TWebPagePortal = class(TWebPage)
    procedure DataModuleProduce(HandlerData: THTTPHandlerData);
  private
    Session: TWebSession;
    function ShowPanel(Title, Content: string; Menu: TStrings = nil): string;
    function SystemMessage(Title, Text: string): string;
    function ShowLinks(GroupId: Integer): string;
    procedure Show(HandlerData: THTTPHandlerData);
    function OnlineHostList: string;
    function UserPanel: string;
    function WebcamPanel: string;
  public
    ModuleUser: TModuleUser;
    ModuleNews: TModuleNews;
  end;

var
  WebPagePortal: TWebPagePortal;


implementation

{$R *.lfm}

uses
  Core, WebObjects, User;

function TWebPagePortal.SystemMessage(Title, Text: string): string;
begin
  Result := '<table align="center"><tr><td><div class="SystemMessage"><h3>' +
    Title + '</h3><div>' + Text + '</div></div</td></tr></table>';
end;

procedure TWebPagePortal.DataModuleProduce(HandlerData: THTTPHandlerData);
begin
  Session := TWebSession(HandlerData);
  with TWebSession(HandlerData) do begin
    Show(HandlerData);
    GeneratePage(Self);
  end;
end;

function TWebPagePortal.ShowLinks(GroupId: Integer): string;
var
  HyperlinkGroups: TDbRows;
  Hyperlinks: TDbRows;
  Hyperlink: TDictionaryStringString;
  I: Integer;
begin
  try
    HyperlinkGroups := TDbRows.Create;
    Hyperlinks := TDbRows.Create;
    Session.Database.Query(HyperlinkGroups, 'SELECT * FROM `HyperlinkGroup` WHERE `Id`=' + IntToStr(GroupId));

    Result := '';
    Session.Database.Query(Hyperlinks, 'SELECT * FROM `Hyperlink` WHERE (`Group`=' + IntToStr(GroupId) + ') AND (`Enable` = 1)');
    for I := 0 to HyperLinks.Count - 1 do begin
      HyperLink := Hyperlinks[I];
      if HyperLink.Items['IconFile'] = '' then
          HyperLink.Items['IconFile'] := 'clear.png';
        if Copy(HyperLink.Items['URL'], 1, 4) <> 'http' then
          HyperLink.Items['URL'] := NavigationLink(HyperLink.Items['URL']);
        if ((HyperLink.Items['PermissionModule'] = '') or
        ((HyperLink.Items['PermissionModule'] <> '') and
        ModuleUser.User.CheckPermission(HyperLink.Items['PermissionModule'], HyperLink.Items['PermissionOperation']))) then
        Result := Result + '<img alt="' + HyperLink.Items['Name'] + '" src="images/favicons/' + HyperLink.Items['IconFile'] + '" width="16" height="16" /> <a href="' + HyperLink.Items['URL'] + '">' + HyperLink.Items['Name'] + '</a><br />';
    end;
    Result := ShowPanel(HyperlinkGroups[0].Items['Name'], Result);

  finally
    HyperlinkGroups.Free;
    Hyperlinks.Free;
  end;
end;

procedure TWebPagePortal.Show(HandlerData: THTTPHandlerData);
var
  Output: string;
  Form: TQueryForm;
  UserOptions: TQueryForm;
  PanelColumn: TDictionaryStringString;
  Panel: TDictionaryStringString;
  Width: string;
  DbRows: TDbRows;
  DbRows2: TDbRows;
  I, J: Integer;
  Action: string;
begin
  try
    DbRows := TDbRows.Create;
    DbRows2 := TDbRows.Create;
  Output := '';
  with Session.Request do
  if Query.TryGetValue('Action', Action) then begin
    if Action = 'CustomizeNewsSave' then begin
      //Output := $this->System->Modules['News']->CustomizeSave();
    end else
    if Action = 'LoginForm' then begin
      Form := TQueryForm.Create; // UserLogin
      Form.AddNewAction('Přihlásit', '?Action=Login');
      Output := Output + Form.AsXmlElement.AsString;
      Output := Output + '<div class="Centred"><a href="?Action=UserRegister">Registrovat se</a> ' +
        '<a href="?Action=PasswordRecovery">Obnova zapomenutého hesla</a></div>';
    end else
    if Action = 'Login' then begin
      Form := TQueryForm.Create; // UserLogin
      Form.Load(Session.Request.Post);
      ModuleUser.UserOnline.Login(
        ModuleUser.User.GetIdByNamePassword(
      TQueryFormGroup(Form.Groups[0]).Rows.FindByName('Username').Value.Value,
        TQueryFormGroup(Form.Groups[0]).Rows.FindByName('Password').Value.Value));
      Output := Output + SystemMessage('Přihlášení', 'Přihlášení provedeno');
      if ModuleUser.User.Id <> UnknownUser then begin
        //Form.LoadValuesFromForm;
        TQueryFormGroup(Form.Groups[0]).Rows.FindByName('Password').Value.Value := '';
        Output := Output + Form.AsXmlElement.AsString;
        Output := Output + '<div class="Centred"><a href="?Action=UserRegister">Registrovat se</a> ' +
          '<a href="?Action=PasswordRecovery">Obnova zapomenutého hesla</a></div>';
      end;
    end else
    if Action = 'Logout' then begin
      ModuleUser.UserOnline.Logout;
      Output := Output + SystemMessage('Odhlášení', 'Uživatel odhlášen');
    end else
    if Action = 'UserOptions' then begin
      UserOptions := TQueryForm.Create; // UserOptions
      //UserOptions.LoadValuesFromDatabase(Session.User.Id);
      UserOptions.AddNewAction('Uložit', '?Action=UserOptionsSave');
      Output := Output + UserOptions.AsXmlElement.AsString;
    end else
    if Action = 'UserOptionsSave' then begin
      UserOptions := TQueryForm.Create; // UserOptions
      UserOptions.Load(Session.Request.Post);
      //UserOptions.SaveValuesToDatabase($this->System->Modules['User']->User['Id']);
      Output := Output + SystemMessage('Nastavení', 'Nastavení uloženo.');
      //this->System->Modules['Log']->NewRecord('User', 'Nastavení uživatele změněno', $UserOptions->Values['Name']);
      //UserOptions.LoadValuesFromDatabase($this->System->Modules['User']->User['Id']);
      UserOptions.AddNewAction('Uložit', '?Action=UserOptionsSave');
      Output := Output + UserOptions.AsXmlElement.AsString;
    end else
    if Action = 'UserRegister' then begin
      Form := TQueryForm.Create; //'UserRegister');
      Form.Load(Session.Request.Post);
      Form.AddNewAction('Uložit', '?Action=UserRegisterSave');
      Output := Output + Form.AsXmlElement.AsString;
    end else
    if Action = 'UserRegisterConfirm' then begin
      //Session.User.RegisterConfirm($_GET['User'], $_GET['H']);
      Output := Output + SystemMessage('Potvrzení registrace', 'Registrace potvrzena');
    end else
    if Action = 'PasswordRecovery' then begin
      Form := TQueryForm.Create; // PasswordRecovery
      Form.AddNewAction('Obnovit', '?Action=PasswordRecovery2');
      Output := Output + Form.AsXmlElement.AsString;
    end else
    if Action = 'PasswordRecovery2' then begin
      Form := TQueryForm.Create; // PasswordRecovery
      Form.Load(Session.Request.Post);
      //Result = Session.User.PasswordRecoveryRequest($Form->Values['Name'], $Form->Values['Email']);
      Output := Output + SystemMessage('Obnova hesla', 'Heslo obnoveno');
      //if Result <> USER_PASSWORD_RECOVERY_SUCCESS then begin
        Output := Output + Form.AsXmlElement.AsString;
      //end;
    end else
    if Action = 'PasswordRecoveryConfirm' then begin
      //Session.User.PasswordRecoveryConfirm($_GET['User'], $_GET['H'], $_GET['P']);
      Output := Output + SystemMessage('Obnova hesla', 'Potvrzení obnovení hesla');
    end (*else
    if Action = 'UserRegisterSave' then begin
          Form := TQueryForm.Create; // UserRegister
          Form.Load(Session.Request.Post);
          Session.User.Register(Form->Values['Login'], $Form->Values['Password'], $Form->Values['Password2'], $Form->Values['Email'], $Form->Values['Name'], $Form->Values['PhoneNumber'], $Form->Values['ICQ']);
          $Output := Output + $this->SystemMessage('Registrace nového účtu', $Result);
          if Result <> USER_REGISTRATED then begin
            Form.OnSubmit := '?Action=UserRegisterSave';
            $Output := Output + Form.ShowEditForm;
      end;
    end else
    if Action = 'MemberOptions' then begin
          $UserOptions = new Form('MemberOptions');
          $DbResult = $this->Database->query('SELECT Member.Id, Member.InternetTariffNextMonth, Member.FamilyMemberCount, Member.BillingPeriodNext, Subject.Name, Subject.AddressStreet, Subject.AddressTown, Subject.AddressPSC, Subject.IC, Subject.DIC FROM Member JOIN Subject ON Subject.Id = Member.Subject WHERE Member.Id='.$this->System->Modules['User']->User['Member']);
          $DbRow = $DbResult->fetch_array();
          foreach($UserOptions->Definition['Items'] as $Index => $Item)
          begin
            $UserOptions->Values[$Index] = $DbRow[$Index];
          end;
          $UserOptions->OnSubmit = '?Action=MemberOptionsSave';
          $Output .= $UserOptions->ShowEditForm();
     end else
     if Action = 'MemberOptionsSave' then begin
          $UserOptions = new Form('MemberOptions');
          $UserOptions->LoadValuesFromForm();
          if($UserOptions->Values['FamilyMemberCount'] < 0)
            $UserOptions->Values['FamilyMemberCount'] = 0;
          if($UserOptions->Values['BillingPeriodNext'] < 2)
            $UserOptions->Values['BillingPeriodNext'] = 2;

          $DbResult = $this->Database->update('Member', 'Id='.$this->System->Modules['User']->User['Member'], array('InternetTariffNextMonth' => $UserOptions->Values['InternetTariffNextMonth'], 'FamilyMemberCount' => $UserOptions->Values['FamilyMemberCount'], 'BillingPeriodNext' => $UserOptions->Values['BillingPeriodNext']));
          $DbResult = $this->Database->query('SELECT Subject FROM Member WHERE Id='.$this->System->Modules['User']->User['Member']);
          $Member = $DbResult->fetch_assoc();
          $DbResult = $this->Database->update('Subject', 'Id='.$Member['Subject'], array('Name' => $UserOptions->Values['Name'], 'AddressStreet' => $UserOptions->Values['AddressStreet'], 'AddressTown' => $UserOptions->Values['AddressTown'], 'AddressPSC' => $UserOptions->Values['AddressPSC'], 'IC' => $UserOptions->Values['IC'], 'DIC' => $UserOptions->Values['DIC']));
          $Output .= $this->SystemMessage('Nastavení', 'Nastavení domácnosti uloženo.');
          $this->System->Modules['Log']->NewRecord('Member+Subject', 'Nastavení člena/subjektu změněno', $UserOptions->Values['Name']);
          $DbResult = $this->Database->query('SELECT Member.Id, Member.InternetTariffNextMonth, Member.FamilyMemberCount, Member.BillingPeriodNext, Subject.Name, Subject.AddressStreet, Subject.AddressTown, Subject.AddressPSC, Subject.IC, Subject.DIC FROM Member JOIN Subject ON Subject.Id = Member.Subject WHERE Member.Id='.$this->System->Modules['User']->User['Member']);
          $DbRow = $DbResult->fetch_array();
          foreach($UserOptions->Definition['Items'] as $Index => $Item)
          {
            $UserOptions->Values[$Index] = $DbRow[$Index];
          }
          $UserOptions->OnSubmit = '?Action=MemberOptionsSave';
          $Output .= $UserOptions->ShowEditForm();
      end;
    end *);
    end;

    //Session.Database.Database := Config['Database']['Database'];

    // Show pannels
    //if(IsInternetAddr()) echo('Internet'); else echo('LAN');
    // $Output .= $this->InfoBar();
    Output := Output + '<table id="MainTable"><tr>';
    Session.Database.Select(DbRows, 'PanelColumn', '*');
    for I := 0 to DbRows.Count - 1 do begin
      PanelColumn := DbRows[I];
      if PanelColumn.Items['Width'] <> '' then
          Width := ' width="' + PanelColumn.Items['Width'] + '"'
        else Width := '';
      Output := Output + '<td valign="top"' + Width + '>';
      Session.Database.Query(DbRows2, 'SELECT * FROM `Panel` WHERE `PanelColumn`=' +
        PanelColumn.Items['Id'] + ' ORDER BY `Order`');
      for J := 0 to DbRows2.Count - 1 do begin
        Panel := DbRows2[J];
        if Panel.Items['Module'] = 'HyperlinkGroup' then
          Output := Output + ShowLinks(StrToInt(Panel.Items['Parameters']))
        else if Panel.Items['Module'] = 'OnlineHostList' then
          Output := Output + ShowPanel('Online počítače', OnlineHostList)
        else if Panel.Items['Module'] = 'UserOptions' then
        begin
          if ModuleUser.User.Id <> UnknownUser then
            Output := Output + ShowPanel('Přihlášený uživatel', UserPanel);
        end else
        if Panel.Items['Module'] = 'Webcam' then
          Output := Output + ShowPanel('Kamery', WebcamPanel)
        else if Panel.Items['Module'] = 'NewsGroupList' then
          Output := Output + ShowPanel('Aktuality',
          ModuleNews.Show(HandlerData)); //,
          //['<a href="?Action=CustomizeNews">Upravit</a>']);
      end;
      Output := Output + '</td>';
    end;
    Output := Output + '</tr></table>';
    with TWebSession(HandlerData) do begin
      with HtmlDocument.Body, SubItems.AddString do
        Text := Text + Output;
    end;
  finally
    DbRows2.Free;
    DbRows.Free;
  end;
end;

function TWebPagePortal.OnlineHostList: string;
begin
  Result := '';
end;

function TWebPagePortal.UserPanel: string;
begin
  Result := '';
end;

function TWebPagePortal.ShowPanel(Title, Content: string; Menu: TStrings): string;
var
  I: Integer;
  TitleCombined: string;
begin
  TitleCombined := '';
  if Assigned(Menu) then
    if Menu.Count > 0 then
      for I := 0 to Menu.Count - 1 do
        TitleCombined := TitleCombined + '<div class="Action">' + Menu[I] + '</div>';
  Result := '<div class="Panel"><div class="Title">' + TitleCombined +
    '</div><div class="Content">' + Content + '</div></div>';
end;

function TWebPagePortal.WebcamPanel: string;
begin
  Result := '';
end;

end.

