unit ModuleTV;

interface

uses
  Classes, SysUtils, ModularSystem, ModuleBase, UWebPage;

type

  { TModuleUser }

  TModuleTV = class(TModule)
  private
    WebPageTV: TWebPage;
  public
    ModuleBase: TModuleBase;
    constructor Create(Owner: TComponent); override;
    destructor Destroy; override;
    procedure Start; override;
    procedure Stop; override;
    procedure Install; override;
    procedure Uninstall; override;
    procedure Upgrade; override;
  end;


implementation

uses
  Core, PageTV, USqlDatabase;

{ TModuleTV }

constructor TModuleTV.Create(Owner: TComponent);
begin
  inherited;
  Identification := 'TV';
  Title := 'Television channels';
  Version := '1.0';
  License := 'GNU/LGPL v3';
  Author := 'Chronosoft';
  Dependencies.Add('Base');
end;

destructor TModuleTV.Destroy;
begin
  inherited;
end;

procedure TModuleTV.Start;
begin
  BeforeStart;
  ModuleBase := TModuleBase(Manager.FindModuleByName('Base'));
  WebPageTV := TWebPageTV.Create(nil);
  ModuleBase.Pages.RegisterPage(WebPageTV, 'tv');
  AfterStart;
end;

procedure TModuleTV.Stop;
begin
  BeforeStop;
  ModuleBase.Pages.UnregisterPage(WebPageTV);
  FreeAndNil(WebPageTV);
  ModuleBase := nil;
  AfterStop;
end;

procedure TModuleTV.Install;
var
  DbRows: TDbRows;
begin
  try
    DbRows := TDbRows.Create;

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `TV` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Name` varchar(16) COLLATE utf8_czech_ci NOT NULL,' +
    '  `Frequency` int(11) NOT NULL DEFAULT "0",' +
    '  `Norm` varchar(8) COLLATE utf8_czech_ci NOT NULL,' +
    '  `Homepage` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  `Language` varchar(32) COLLATE utf8_czech_ci NOT NULL,' +
    '  `ShortName` varchar(16) COLLATE utf8_czech_ci NOT NULL,' +
    '  `Stream` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  `StreamWeb` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  `SourceType` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  `Category` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  PRIMARY KEY (`Id`)' +
    ') ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1 ;');

  finally
    DbRows.Free;
  end;
  inherited Install;
end;

procedure TModuleTV.Uninstall;
var
  DbRows: TDbRows;
begin
  inherited Uninstall;
  try
    DbRows := TDbRows.Create;
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `TV`');
  finally
    DbRows.Free;
  end;
end;

procedure TModuleTV.Upgrade;
begin
  inherited;
end;

end.

