unit ModuleUser;

interface

uses
  Classes, SysUtils, ModularSystem, User, ModuleBase, UWebPage;

type
  { TModuleUser }

  TModuleUser = class(TModule)
  private
    UserControlPage: TWebPage; //TUserControlPage;
  public
    User: TWebUser;
    UserOnline: TWebOnlineUser;
    ModuleBase: TModuleBase;
    constructor Create(Owner: TComponent); override;
    destructor Destroy; override;
    procedure Start; override;
    procedure Stop; override;
    procedure Install; override;
    procedure Uninstall; override;
    procedure Upgrade; override;
    procedure LoadUserInfo;
  end;


implementation

uses
  Core, USqlDatabase, UserControlPage;

{ TModuleUser }

constructor TModuleUser.Create(Owner: TComponent);
begin
  inherited;
  Identification := 'User';
  Title := 'User management';
  Version := '1.0';
  License := 'GNU/LGPL v3';
  Author := 'Chronosoft';
  Dependencies.Add('Base');
end;

destructor TModuleUser.Destroy;
begin
  inherited;
end;

procedure TModuleUser.Start;
begin
  BeforeStart;
  ModuleBase := TModuleBase(Manager.FindModuleByName('Base'));
  UserControlPage := TUserControlPage.Create(nil);
  ModuleBase.Pages.RegisterPage(UserControlPage, 'uzivatel');
  //RegisterPage(TUserControlPage, UserControlPage, '');
  User := TWebUser.Create;
  User.Database := ModuleBase.Session.Database;
  User.HandlerData := ModuleBase.Session;
  UserOnline := TWebOnlineUser.Create;
  UserOnline.Database := ModuleBase.Session.Database;
  UserOnline.HandlerData := ModuleBase.Session;
  AfterStart;
end;

procedure TModuleUser.Stop;
begin
  BeforeStop;
  FreeAndNil(User);
  FreeAndNil(UserOnline);
  ModuleBase.Pages.UnregisterPage(UserControlPage);
  FreeAndNil(UserControlPage);
  ModuleBase := nil;
  AfterStop;
end;

procedure TModuleUser.Install;
var
  DbRows: TDbRows;
begin
  try
    DbRows := TDbRows.Create;

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `User` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Name` varchar(255) NOT NULL,' +
    '  `FullName` varchar(255) NOT NULL,' +
    '  `Password` varchar(255) NOT NULL,' +
    '  `Salt` varchar(255) NOT NULL,' +
    '  `Email` varchar(255) NOT NULL,' +
    '  `RegistrationTime` datetime NOT NULL,' +
    '  PRIMARY KEY (`Id`)' +
    ') ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;');

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `UserOnline` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `User` int(11) NOT NULL DEFAULT ''0'',' +
    '  `ActivityTime` datetime NOT NULL DEFAULT ''0000-00-00 00:00:00'',' +
    '  `LoginTime` datetime NOT NULL DEFAULT ''0000-00-00 00:00:00'',' +
    '  `SessionId` varchar(255) COLLATE utf8_czech_ci NOT NULL DEFAULT '''',' +
    '  `IpAddress` varchar(16) COLLATE utf8_czech_ci NOT NULL DEFAULT '''',' +
    '  `HostName` varchar(255) COLLATE utf8_czech_ci NOT NULL DEFAULT '''',' +
    '  `ScriptName` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  PRIMARY KEY (`Id`),' +
    '  KEY `User` (`User`)' +
    ') ENGINE=MEMORY  DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1 ;');

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `PermissionGroup` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Description` varchar(255) COLLATE utf8_czech_ci NOT NULL DEFAULT "",' +
    '  PRIMARY KEY (`Id`)' +
    ') ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1 ;');

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `PermissionGroupAssignment` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Group` int(11) NOT NULL DEFAULT "0",' +
    '  `AssignedGroup` int(11) DEFAULT NULL,' +
    '  `AssignedOperation` int(11) DEFAULT NULL,' +
    '  PRIMARY KEY (`Id`),' +
    '  KEY `Group` (`Group`),' +
    '  KEY `AssignedGroup` (`AssignedGroup`),' +
    '  KEY `AssignedOperation` (`AssignedOperation`)' +
    ') ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1 ;');

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `PermissionOperation` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Module` varchar(64) COLLATE utf8_czech_ci NOT NULL DEFAULT "",' +
    '  `Operation` varchar(128) COLLATE utf8_czech_ci NOT NULL DEFAULT "",' +
    '  `Item` varchar(64) COLLATE utf8_czech_ci NOT NULL DEFAULT "",' +
    '  `ItemId` int(11) NOT NULL DEFAULT "0",' +
    '  PRIMARY KEY (`Id`),' +
    '  KEY `Module` (`Module`),' +
    '  KEY `Operation` (`Operation`),' +
    '  KEY `Item` (`Item`),' +
    '  KEY `ItemId` (`ItemId`)' +
    ') ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1 ;');

    Core.Core.CommonDatabase.Query(DbRows,
    '  CREATE TABLE IF NOT EXISTS `PermissionUserAssignment` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `User` int(11) NOT NULL DEFAULT "0",' +
    '  `AssignedGroup` int(11) DEFAULT NULL,' +
    '  `AssignedOperation` int(11) DEFAULT NULL,' +
    '  PRIMARY KEY (`Id`),' +
    '  KEY `User` (`User`),' +
    '  KEY `AssignedGroup` (`AssignedGroup`),' +
    '  KEY `AssignedOperation` (`AssignedOperation`)' +
    ') ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1 ;');

    Core.Core.CommonDatabase.Query(DbRows,
    'ALTER TABLE `PermissionGroupAssignment`' +
    '  ADD CONSTRAINT `PermissionGroupAssignment_ibfk_1` FOREIGN KEY (`Group`) REFERENCES `permissiongroup` (`Id`),' +
    '  ADD CONSTRAINT `PermissionGroupAssignment_ibfk_2` FOREIGN KEY (`AssignedGroup`) REFERENCES `permissiongroup` (`Id`),' +
    '  ADD CONSTRAINT `PermissionGroupAssignment_ibfk_3` FOREIGN KEY (`AssignedOperation`) REFERENCES `permissionoperation` (`Id`);');

    Core.Core.CommonDatabase.Query(DbRows,
    'ALTER TABLE `PermissionUserAssignment`' +
    '  ADD CONSTRAINT `PermissionUserAssignment_ibfk_1` FOREIGN KEY (`User`) REFERENCES `user` (`Id`),' +
    '  ADD CONSTRAINT `PermissionUserAssignment_ibfk_2` FOREIGN KEY (`AssignedGroup`) REFERENCES `permissiongroup` (`Id`),' +
    '  ADD CONSTRAINT `PermissionUserAssignment_ibfk_3` FOREIGN KEY (`AssignedOperation`) REFERENCES `permissionoperation` (`Id`);');
  finally
    DbRows.Free;
  end;
  inherited;
end;

procedure TModuleUser.Uninstall;
var
  DbRows: TDbRows;
begin
  inherited;
  try
    DbRows := TDbRows.Create;

    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `PermissionUserAssignment`');
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `PermissionGroupAssignment`');
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `PermissionGroup`');
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `PermissionOperation`');
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `User`');
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `UserOnline`');
  finally
    DbRows.Free;
  end;
end;

procedure TModuleUser.Upgrade;
begin
  inherited;
end;

procedure TModuleUser.LoadUserInfo;
begin
  User.HandlerData := ModuleBase.HandlerData;
  UserOnline.HandlerData := ModuleBase.HandlerData;
  UserOnline.Update;
  User.Id := UserOnline.User;
  User.Load;
end;

end.

