unit ModuleZdechovNET;

interface

uses
  Classes, SysUtils, ModularSystem, UWebPage, RobotsPage,
  WebSession, DateUtils, ModuleBase, ModuleUser, IPTVPage,
  InternetPage, HostingPage, HistoryPage, DocumentsPage, VoIPPage,
  LinksPage, PlansPage, ServerInfoPage, WebCamPage, User,
  NetworkPage, AboutPage, ContactPage, ProjectsPage;

type

  { TModuleZdechovNET }

  TModuleZdechovNET = class(TModule)
  private
    InternetPage: TInternetPage;
    HostingPage: THostingPage;
    HistoryPage: THistoryPage;
    DocumentsPage: TDocumentsPage;
    VoIPPage: TVoIPPage;
    LinksPage: TLinksPage;
    ContactPage: TContactPage;
    ServerInfoPage: TServerInfoPage;
    WebCamPage: TWebCamPage;
    PlansPage: TPlansPage;
    NetworkPage: TNetworkPage;
    ProjectsPage: TProjectsPage;
    AboutPage: TAboutPage;
    IPTVPage: TIPTVPage;
    RobotsPage: TRobotsPage;
    procedure Footer(Session: TWebSession);
    procedure GeneratePage(ASession: TWebSession; Page: TWebPage);
    procedure TopMenu(Session: TWebSession);
  public
    ModuleBase: TModuleBase;
    ModuleUser: TModuleUser;
    Raw: Boolean;
    constructor Create(Owner: TComponent); override;
    destructor Destroy; override;
    procedure Start; override;
    procedure Stop; override;
    procedure Install; override;
    procedure Uninstall; override;
  end;


implementation

uses
  Core, USqlDatabase, UXmlClasses, UHtmlClasses, Utils;

{ TModuleZdechovNET }

constructor TModuleZdechovNET.Create(Owner: TComponent);
begin
  inherited;
  Identification := 'ZdechovNET';
  Title := 'ZdechovNET web';
  Version := '1.0';
  License := 'GNU/LGPL v3';
  Author := 'Chronosoft';
  Dependencies.Add('User');
  Dependencies.Add('Base');

  // Pages
  InternetPage := TInternetPage.Create(nil);
  HostingPage := THostingPage.Create(nil);
  HistoryPage := THistoryPage.Create(nil);
  DocumentsPage := TDocumentsPage.Create(nil);
  VoIPPage := TVoIPPage.Create(nil);
  LinksPage := TLinksPage.Create(nil);
  ContactPage := TContactPage.Create(nil);
  ServerInfoPage := TServerInfoPage.Create(nil);
  WebCamPage := TWebCamPage.Create(nil);
  PlansPage := TPlansPage.Create(nil);
  NetworkPage := TNetworkPage.Create(nil);
  ProjectsPage := TProjectsPage.Create(nil);
  AboutPage := TAboutPage.Create(nil);
  IPTVPage := TIPTVPage.Create(nil);
  RobotsPage := TRobotsPage.Create(nil);
end;

destructor TModuleZdechovNET.Destroy;
begin
  FreeAndNil(IPTVPage);
  FreeAndNil(AboutPage);
  FreeAndNil(InternetPage);
  FreeAndNil(HostingPage);
  FreeAndNil(HistoryPage);
  FreeAndNil(DocumentsPage);
  FreeAndNil(VoIPPage);
  FreeAndNil(LinksPage);
  FreeAndNil(ContactPage);
  FreeAndNil(ServerInfoPage);
  FreeAndNil(WebCamPage);
  FreeAndNil(PlansPage);
  FreeAndNil(NetworkPage);
  FreeAndNil(ProjectsPage);
  FreeAndNil(RobotsPage);
  inherited;
end;

procedure TModuleZdechovNET.Start;
begin
  BeforeStart;
  ModuleBase := TModuleBase(Manager.FindModuleByName('Base'));
  ModuleBase.OnGeneratePage := GeneratePage;
  ModuleUser := TModuleUser(Manager.FindModuleByName('User'));
  with ModuleBase, Pages do begin
    //OnGeneratePage := OnGeneratePage;

    RegisterPage(InternetPage, 'internet');
    RegisterPage(HostingPage, 'hosting');
    RegisterPage(HistoryPage, 'historie');
    RegisterPage(DocumentsPage, 'dokumenty');
    RegisterPage(VoIPPage, 'voip');
    RegisterPage(LinksPage, 'odkazy');
    RegisterPage(ContactPage, 'kontakt');
    RegisterPage(WebCamPage, 'kamery');
    RegisterPage(PlansPage, 'plany');
    RegisterPage(NetworkPage, 'sit');
    RegisterPage(ProjectsPage, 'projekty');
    RegisterPage(AboutPage, '');
    RegisterPage(IPTVPage, 'televize');
    RegisterPage(RobotsPage, 'robots.txt');
    {$IFDEF DEBUG}
    RegisterPage(ServerInfoPage, 'serverinfo');
    {$ENDIF}
  end;
  AfterStart;
end;

procedure TModuleZdechovNET.Stop;
begin
  BeforeStop;
  with ModuleBase, Pages do begin
    UnregisterPage(IPTVPage);
    UnregisterPage(AboutPage);
    UnregisterPage(InternetPage);
    UnregisterPage(HostingPage);
    UnregisterPage(HistoryPage);
    UnregisterPage(DocumentsPage);
    UnregisterPage(VoIPPage);
    UnregisterPage(LinksPage);
    UnregisterPage(ContactPage);
    UnregisterPage(WebCamPage);
    UnregisterPage(PlansPage);
    UnregisterPage(NetworkPage);
    UnregisterPage(ProjectsPage);
    UnregisterPage(RobotsPage);
    {$IFDEF DEBUG}
    UnregisterPage(ServerInfoPage);
    {$ENDIF}
  end;
  ModuleBase := nil;
  ModuleUser := nil;
  AfterStop;
end;

procedure TModuleZdechovNET.Install;
var
  DbRows: TDbRows;
begin
  try
    DbRows := TDbRows.Create;

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `VPSHosting` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Name` varchar(255) NOT NULL,' +
    '  `Memory` varchar(255) NOT NULL,' +
    '  `Space` varchar(255) NOT NULL,' +
    '  `Internet` varchar(255) NOT NULL,' +
    '  `CPU` varchar(255) NOT NULL,' +
    '  `Price` int(11) NOT NULL,' +
    '  PRIMARY KEY (`Id`)' +
    ') ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;');

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `History` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Date` date NOT NULL,' +
    '  `Text` text COLLATE utf8_czech_ci NOT NULL,' +
    '  PRIMARY KEY (`Id`)' +
    ') ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1 ;');

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `Webcam` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Name` varchar(255) CHARACTER SET utf8 COLLATE utf8_czech_ci NOT NULL,' +
    '  `Description` text CHARACTER SET utf8 COLLATE utf8_czech_ci NOT NULL,' +
    '  `ImageName` varchar(255) CHARACTER SET utf8 COLLATE utf8_czech_ci NOT NULL,' +
    '  `ImageURL` varchar(255) CHARACTER SET utf8 COLLATE utf8_czech_ci NOT NULL,' +
    '  `ImagePeriod` int(11) NOT NULL,' +
    '  `Width` int(11) NOT NULL,' +
    '  `Height` int(11) NOT NULL,' +
    '  `Enabled` int(11) NOT NULL DEFAULT "1",' +
    '  `DeviceType` varchar(255) NOT NULL,' +
    '  PRIMARY KEY (`Id`)' +
    ') ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;');

    Core.Core.CommonDatabase.Query(DbRows,
    '  CREATE TABLE IF NOT EXISTS `Plans` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `TimeCreate` datetime NOT NULL,' +
    '  `TimeFinished` datetime DEFAULT NULL,' +
    '  `Description` text COLLATE utf8_czech_ci NOT NULL,' +
    '  `Conclusion` text COLLATE utf8_czech_ci NOT NULL,' +
    '  `Public` int(11) NOT NULL DEFAULT "0",' +
    '  PRIMARY KEY (`Id`),' +
    '  KEY `TimeCreate` (`TimeCreate`),' +
    '  KEY `TimeFinished` (`TimeFinished`)' +
    ') ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1 ;');

    Core.Core.CommonDatabase.Query(DbRows,
    'CREATE TABLE IF NOT EXISTS `HostedProject` (' +
    '  `Id` int(11) NOT NULL AUTO_INCREMENT,' +
    '  `Name` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  `Homepage` varchar(255) COLLATE utf8_czech_ci NOT NULL,' +
    '  `User` int(255) NOT NULL COMMENT "User.Id",' +
    '  `TimeCreate` datetime NOT NULL,' +
    '  `Server` int(11) DEFAULT NULL COMMENT "NetworkDevice.Id",' +
    '  `Active` int(11) NOT NULL DEFAULT "1",' +
    '  `WebHosting` int(11) NOT NULL,' +
    '  PRIMARY KEY (`Id`)' +
    ') ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci AUTO_INCREMENT=1 ;');

  finally
    DbRows.Free;
  end;

  inherited;
end;

procedure TModuleZdechovNET.Uninstall;
var
  DbRows: TDbRows;
begin
  inherited;
  ModuleBase.OnGeneratePage := nil;
  try
    DbRows := TDbRows.Create;
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `HostedProject`');
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `Plans`');
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `Webcam`');
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `VPSHosting`');
    Core.Core.CommonDatabase.Query(DbRows, 'DROP TABLE IF EXISTS `History`');
  finally
    DbRows.Free;
  end;
end;

procedure TModuleZdechovNET.Footer(Session: TWebSession);
var
  Tag: TXMLTag;
  AdminTag: TXMLTag;
  EmailTag: TXMLTag;
  ExecutionTimeTag: TXMLTag;
  UsedMemoryTag: TXMLTag;
  TextNode: TXmlString;
begin
  with Session do
  with HtmlDocument.Body.SubItems.AddList do begin
    ClassId := 'Footer';
    with SubItems.AddString do begin
      Text := TCore(MainModule).Admin;
    end;
    with SubItems.AddString do begin
      Text := TCore(MainModule).AdminEmail;
    end;
    if TCore(MainModule).ShowRuntimeInfo then begin
      with SubItems.AddString do begin
        Text := 'Doba generování: ' +
          FloatToStr(Round(((Now - TimeStart) / OneMillisecond) * 100) / 100) + ' s / '; // + ini_get('max_execution_time') + ' s';
      end;
      with SubItems.AddString do begin
        //Text := 'Použitá paměť: '  + System.PrefixMultiplier.AddPrefixMultipliers(memory_get_peak_usage(FALSE), 'B').' / '.ini_get('memory_limit').'B';
      end;
    end;
  end;
end;

procedure TModuleZdechovNET.TopMenu(Session: TWebSession);
var
  Output: THtmlString;
begin
  Output := THtmlString.Create;
  Session.HtmlDocument.Body.SubItems.Insert(1, Output);
  with Output do begin
    Text := '<div class="Navigation">';
    // Visitor
    Text := Text + '<ul class="MenuItem">' +
      '<li>' + MakeLink('Úvod', NavigationLink('/')) + '</li>' +
      '<li>' + MakeLink('Internet', NavigationLink('/internet/')) + '</li>' +
      '<li>' + MakeLink('Televize', NavigationLink('/televize/')) + '</li>' +
      '<li>' + MakeLink('Hosting', NavigationLink('/hosting/')) + '</li>' +
      '<li>' + MakeLink('VoIP', NavigationLink('/voip/')) + '</li>' +
      '<li>' + MakeLink('Síť', NavigationLink('/sit/')) + '</li>' +
      '<li>' + MakeLink('Odkazy', NavigationLink('/odkazy/')) + '</li>' +
      '<li>' + MakeLink('Kontakt', NavigationLink('/kontakt/')) + '</li>' +
      '<li>' + MakeLink('Kamery', NavigationLink('/kamery/')) + '</li>' +
      '<li><a href="https://mail.zdechov.net/">Pošta</a></li>' +
      '<li><a href="https://wiki.zdechov.net/">Wiki</a></li>' +
      '</ul><ul class="MenuItem2">'; //<li>&nbsp;</li>';
    if False and Assigned(ModuleBase.Pages.FindByName('uzivatel')) then begin
      if ModuleUser.UserOnline.User = UnknownUser then begin
        Text := Text + '</ul>' +
          '<ul class="MenuItem2">' +
          '<li>' + MakeLink('Přihlášení', NavigationLink('/uzivatel/prihlaseni/')) + '</li>' +
          '<li>' + MakeLink('Registrace', NavigationLink('/uzivatel/registrace/')) + '</li>' +
          '<li></li>';
        // $Output .= '<li>'.$this->System->HTML->MakeLink($this->System->Translate('UserRegistration'), $this->System->MakeLink('UserList', 'Register')).'</li>';
      end else begin
        Text := Text + '</ul>' +
          '<ul class="MenuItem2">' +
          '<li>' + ModuleUser.User.FullName + '</li>' +
          '<li>' + MakeLink('Odhlášení', NavigationLink('/uzivatel/odhlaseni/')) + '</li>' +
          '<li>' + MakeLink('Profil', NavigationLink('/uzivatel/profil/')) + '</li>';
      end;
    end else Text := Text + '</ul><ul class="MenuItem2">';
    Text := Text + '</ul></div>';
  end;
end;

procedure TModuleZdechovNET.GeneratePage(ASession: TWebSession; Page: TWebPage);
var
  I: Integer;
  TitleTag: THtmlString;
  TopMenuTag: THtmlString;
begin
  with ASession do begin
    if Page.Raw then begin
      Response.Content.WriteString(HtmlDocument.Body.AsXmlElement.AsString);
    end else begin
      HtmlDocument.ContentLanguage := 'cs';
      GlobalTitle := 'ZděchovNET';
      HtmlDocument.Styles.Add(NavigationLink('/Style/' + TCore(MainModule).Style + '/Style.css'));
      HtmlDocument.Scripts.Add(NavigationLink('/Style/' + TCore(MainModule).Style + '/Global.js'));
      HtmlDocument.Scripts.Add(NavigationLink('/Style/' + TCore(MainModule).Style + '/jquery.js'));

      TitleTag := THtmlString.Create;
      HtmlDocument.Body.SubItems.Insert(0, TitleTag);
      TopMenu(ASession);
      //Page.Page.OnProduce(HandlerData);
      HtmlDocument.Title := Page.Caption;
      TitleTag.Text := '<div class="TitlePanel"><span class="GlobalTitle">' + GlobalTitle +
        '</span> - ' + HtmlDocument.Title + '</div>';
      HtmlDocument.Title := GlobalTitle + ' - ' + HtmlDocument.Title;
      with HtmlDocument.AsXmlDocument do
      try
        Formated := TCore(MainModule).FormatHTML;
        Response.Content.WriteString(AsString);
      finally
        Free;
      end;
    end;
  end;
end;

end.

